const app = getApp();
const api = require('../../utils/api.js');

Page({
  data: {
    isLoggedIn: false,
    userInfo: null,
    hasSignedToday: false,
    endTimeFormatted: '',
    showKami: false,
    kamiCode: '',
    showResult: false,
    resultSuccess: false,
    resultTitle: '',
    resultMessage: '',
    rewardedVideoAd: null
  },
  
  onLoad: function() {
    this.checkLoginStatus();
    this.initRewardedVideoAd();
  },
  
  onShow: function() {
    this.checkLoginStatus();
  },
  
  initRewardedVideoAd: function() {
    // 初始化激励视频广告
    if (wx.createRewardedVideoAd) {
      this.data.rewardedVideoAd = wx.createRewardedVideoAd({
        adUnitId: 'adunit-6a659d5afcd9ca0a' // 替换为您的广告单元ID
      });
      
      this.data.rewardedVideoAd.onError(err => {
        console.error('激励视频广告加载失败', err);
      });
      
      this.data.rewardedVideoAd.onClose(res => {
        // 用户点击了【关闭广告】按钮
        if (res && res.isEnded || res === undefined) {
          // 正常播放结束，可以下发奖励
          this.doSignIn();
        } else {
          // 播放中途退出，不下发奖励
          wx.showToast({
            title: '观看完整视频才能获得奖励',
            icon: 'none'
          });
        }
      });
    }
  },
  
  checkLoginStatus: function() {
    const token = wx.getStorageSync('userToken');
    const userInfo = wx.getStorageSync('userInfo');
    
    if (token && userInfo) {
      api.userApi.checkLogin(token).then(res => {
        if (res.success) {
          this.setData({
            isLoggedIn: true,
            userInfo: userInfo
          });
          
          // 格式化到期时间
          if (userInfo.user_end_time > 0) {
            const endTime = new Date(userInfo.user_end_time * 1000);
            const endTimeStr = endTime.getFullYear() + '/' + 
                              (endTime.getMonth() + 1) + '/' + 
                              endTime.getDate();
            this.setData({
              endTimeFormatted: endTimeStr
            });
          }
          
          // 检查今日是否已签到
          this.checkSignStatus(token);
          
          // 刷新用户信息
          this.refreshUserInfo(token);
        } else {
          this.setData({
            isLoggedIn: false,
            userInfo: null
          });
          wx.removeStorageSync('userToken');
          wx.removeStorageSync('userInfo');
        }
      }).catch(err => {
        console.error('检查登录状态失败', err);
        this.setData({
          isLoggedIn: false,
          userInfo: null
        });
      });
    } else {
      this.setData({
        isLoggedIn: false,
        userInfo: null
      });
    }
  },
  
  refreshUserInfo: function(token) {
    api.userApi.getUserInfo(token).then(res => {
      if (res.success) {
        wx.setStorageSync('userInfo', res.userInfo);
        this.setData({
          userInfo: res.userInfo
        });
        
        // 格式化到期时间
        if (res.userInfo.user_end_time > 0) {
          const endTime = new Date(res.userInfo.user_end_time * 1000);
          const endTimeStr = endTime.getFullYear() + '/' + 
                            (endTime.getMonth() + 1) + '/' + 
                            endTime.getDate();
          this.setData({
            endTimeFormatted: endTimeStr
          });
        }
      }
    }).catch(err => {
      console.error('获取用户信息失败', err);
    });
  },
  
  checkSignStatus: function(token) {
    api.userApi.checkSignStatus(token).then(res => {
      if (res.success) {
        this.setData({
          hasSignedToday: res.hasSignedToday
        });
      }
    }).catch(err => {
      console.error('检查签到状态失败', err);
    });
  },
  
  goToLogin: function() {
    wx.navigateTo({
      url: '/pages/member/login'
    });
  },
  
  handleSignIn: function() {
    if (!this.data.isLoggedIn) {
      wx.showToast({
        title: '请先登录',
        icon: 'none'
      });
      return;
    }
    
    if (this.data.hasSignedToday) {
      wx.showToast({
        title: '今日已签到',
        icon: 'none'
      });
      return;
    }
    
    // 显示激励视频广告
    if (this.data.rewardedVideoAd) {
      this.data.rewardedVideoAd.show().catch(() => {
        // 失败重试
        this.data.rewardedVideoAd.load()
          .then(() => this.data.rewardedVideoAd.show())
          .catch(err => {
            console.error('激励视频广告显示失败', err);
            wx.showToast({
              title: '广告加载失败，请稍后再试',
              icon: 'none'
            });
          });
      });
    } else {
      // 如果不支持激励视频广告，直接签到
      this.doSignIn();
    }
  },
  
  doSignIn: function() {
    const token = wx.getStorageSync('userToken');
    
    wx.showLoading({
      title: '签到中...',
      mask: true
    });
    
    api.userApi.signIn(token).then(res => {
      wx.hideLoading();
      
      if (res.success) {
        // 更新用户信息
        const userInfo = this.data.userInfo;
        userInfo.user_points = res.newPoints;
        userInfo.user_jifenlq = res.newJifenlq;
        
        wx.setStorageSync('userInfo', userInfo);
        
        this.setData({
          userInfo: userInfo,
          hasSignedToday: true,
          showResult: true,
          resultSuccess: true,
          resultTitle: '签到成功',
          resultMessage: `恭喜您获得${res.points}积分奖励！`
        });
      } else {
        this.setData({
          showResult: true,
          resultSuccess: false,
          resultTitle: '签到失败',
          resultMessage: res.message || '签到失败，请稍后再试'
        });
      }
    }).catch(err => {
      wx.hideLoading();
      console.error('签到失败', err);
      
      this.setData({
        showResult: true,
        resultSuccess: false,
        resultTitle: '签到失败',
        resultMessage: '网络错误，请稍后再试'
      });
    });
  },
  
  showKamiModal: function() {
    if (!this.data.isLoggedIn) {
      wx.showToast({
        title: '请先登录',
        icon: 'none'
      });
      return;
    }
    
    this.setData({
      showKami: true,
      kamiCode: ''
    });
  },
  
  hideKamiModal: function() {
    this.setData({
      showKami: false
    });
  },
  
  onKamiInput: function(e) {
    this.setData({
      kamiCode: e.detail.value
    });
  },
  
  handleUseKami: function() {
    const kamiCode = this.data.kamiCode;
    
    if (!kamiCode) {
      wx.showToast({
        title: '请输入卡密',
        icon: 'none'
      });
      return;
    }
    
    const token = wx.getStorageSync('userToken');
    
    wx.showLoading({
      title: '兑换中...',
      mask: true
    });
    
    api.userApi.useKami(token, kamiCode).then(res => {
      wx.hideLoading();
      
      if (res.success) {
        // 隐藏卡密弹窗
        this.setData({
          showKami: false
        });
        
        // 更新用户信息
        if (res.type === 'integral') {
          // 积分卡
          const userInfo = this.data.userInfo;
          userInfo.user_points = res.newPoints;
          wx.setStorageSync('userInfo', userInfo);
          
          this.setData({
            userInfo: userInfo,
            showResult: true,
            resultSuccess: true,
            resultTitle: '兑换成功',
            resultMessage: res.message || `成功兑换积分卡`
          });
        } else if (res.type === 'vip') {
          // VIP卡
          this.refreshUserInfo(token);
          
          this.setData({
            showResult: true,
            resultSuccess: true,
            resultTitle: '兑换成功',
            resultMessage: res.message || `成功兑换VIP会员`
          });
        }
      } else {
        this.setData({
          showResult: true,
          resultSuccess: false,
          resultTitle: '兑换失败',
          resultMessage: res.message || '卡密兑换失败，请检查卡密是否正确'
        });
      }
    }).catch(err => {
      wx.hideLoading();
      console.error('卡密兑换失败', err);
      
      this.setData({
        showResult: true,
        resultSuccess: false,
        resultTitle: '兑换失败',
        resultMessage: '网络错误，请稍后再试'
      });
    });
  },
  
  hideResultModal: function() {
    this.setData({
      showResult: false
    });
  },
  
  stopPropagation: function() {
    // 阻止事件冒泡
    return;
  },
  
  handleLogout: function() {
    wx.showModal({
      title: '提示',
      content: '确定要退出登录吗？',
      success: (res) => {
        if (res.confirm) {
          wx.removeStorageSync('userToken');
          wx.removeStorageSync('userInfo');
          
          this.setData({
            isLoggedIn: false,
            userInfo: null,
            hasSignedToday: false
          });
          
          wx.showToast({
            title: '已退出登录',
            icon: 'success'
          });
        }
      }
    });
  }
});