const app = getApp();
const api = require('../../utils/api.js');

Page({
  data: {
    username: '',
    password: '',
    showPassword: false,
    loading: false
  },
  
  onLoad: function() {
    // 检查是否已登录
    const token = wx.getStorageSync('userToken');
    if (token) {
      api.userApi.checkLogin(token).then(res => {
        if (res.success) {
          wx.redirectTo({
            url: '/pages/member/center'
          });
        }
      }).catch(err => {
        console.error('检查登录状态失败', err);
      });
    }
  },
  
  onUsernameInput: function(e) {
    this.setData({
      username: e.detail.value
    });
  },
  
  onPasswordInput: function(e) {
    this.setData({
      password: e.detail.value
    });
  },
  
  togglePasswordVisibility: function() {
    this.setData({
      showPassword: !this.data.showPassword
    });
  },
  
  handleLogin: function() {
    const { username, password } = this.data;
    
    if (!username || !password) {
      wx.showToast({
        title: '请输入用户名和密码',
        icon: 'none'
      });
      return;
    }
    
    this.setData({ loading: true });
    
    api.userApi.login(username, password).then(res => {
      this.setData({ loading: false });
      
      if (res.success) {
        // 保存登录信息
        wx.setStorageSync('userToken', res.token);
        wx.setStorageSync('userInfo', res.userInfo);
        
        wx.showToast({
          title: '登录成功',
          icon: 'success',
          duration: 1500,
          success: () => {
            setTimeout(() => {
              wx.redirectTo({
                url: '/pages/member/center'
              });
            }, 1500);
          }
        });
      } else {
        wx.showToast({
          title: res.message || '登录失败',
          icon: 'none'
        });
      }
    }).catch(err => {
      this.setData({ loading: false });
      wx.showToast({
        title: '登录失败，请稍后再试',
        icon: 'none'
      });
      console.error('登录失败', err);
    });
  },
  
  goToRegister: function() {
    wx.showToast({
      title: '请联系管理员注册账号',
      icon: 'none'
    });
  },
  
  goToForgot: function() {
    wx.showToast({
      title: '请联系管理员重置密码',
      icon: 'none'
    });
  }
});