<?php
header('Content-Type: application/json');
header('Access-Control-Allow-Origin: *');
header('Access-Control-Allow-Methods: GET, OPTIONS');
header('Access-Control-Allow-Headers: Content-Type');

// 如果是OPTIONS请求，直接返回200
if ($_SERVER['REQUEST_METHOD'] === 'OPTIONS') {
    http_response_code(200);
    exit;
}

// 引入数据库连接文件
require_once '../../config/database.php';

// 获取token
$token = isset($_GET['token']) ? trim($_GET['token']) : '';

if (empty($token)) {
    echo json_encode([
        'success' => false,
        'message' => '未提供token'
    ]);
    exit;
}

try {
    // 查询用户 - 适配mac_user表
    $stmt = $conn->prepare("SELECT user_id, user_qiandao, token_expire FROM mac_user WHERE user_token = ?");
    $stmt->bind_param("s", $token);
    $stmt->execute();
    $result = $stmt->get_result();
    
    if ($result->num_rows === 0) {
        echo json_encode([
            'success' => false,
            'message' => '无效的token'
        ]);
        exit;
    }
    
    $user = $result->fetch_assoc();
    
    // 检查token是否过期
    if ($user['token_expire'] < time()) {
        echo json_encode([
            'success' => false,
            'message' => 'token已过期'
        ]);
        exit;
    }
    
    // 检查今日是否已签到 - 适配user_qiandao字段
    $today = date('Y-m-d');
    $hasSignedToday = ($user['user_qiandao'] == $today);
    
    echo json_encode([
        'success' => true,
        'hasSignedToday' => $hasSignedToday
    ]);
    
} catch (Exception $e) {
    echo json_encode([
        'success' => false,
        'message' => '检查签到状态失败: ' . $e->getMessage()
    ]);
}
?>