<?php
header('Content-Type: application/json');
header('Access-Control-Allow-Origin: *');
header('Access-Control-Allow-Methods: GET, OPTIONS');
header('Access-Control-Allow-Headers: Content-Type');

// 如果是OPTIONS请求，直接返回200
if ($_SERVER['REQUEST_METHOD'] === 'OPTIONS') {
    http_response_code(200);
    exit;
}

// 引入数据库连接文件
require_once '../../config/database.php';

// 获取token
$token = isset($_GET['token']) ? trim($_GET['token']) : '';

if (empty($token)) {
    echo json_encode([
        'success' => false,
        'message' => '未提供token'
    ]);
    exit;
}

try {
    // 查询用户 - 适配mac_user表
    $stmt = $conn->prepare("SELECT user_id, user_name, group_id, user_points, user_jifenlq, user_end_time, token_expire FROM mac_user WHERE user_token = ?");
    $stmt->bind_param("s", $token);
    $stmt->execute();
    $result = $stmt->get_result();
    
    if ($result->num_rows === 0) {
        echo json_encode([
            'success' => false,
            'message' => '无效的token'
        ]);
        exit;
    }
    
    $user = $result->fetch_assoc();
    
    // 检查token是否过期
    if ($user['token_expire'] < time()) {
        echo json_encode([
            'success' => false,
            'message' => 'token已过期'
        ]);
        exit;
    }
    
    // 返回用户信息
    echo json_encode([
        'success' => true,
        'userInfo' => [
            'user_id' => $user['user_id'],
            'user_name' => $user['user_name'],
            'group_id' => $user['group_id'],
            'user_points' => $user['user_points'],
            'user_jifenlq' => $user['user_jifenlq'],
            'user_end_time' => $user['user_end_time']
        ]
    ]);
    
} catch (Exception $e) {
    echo json_encode([
        'success' => false,
        'message' => '获取用户信息失败: ' . $e->getMessage()
    ]);
}
?>