<?php
header('Content-Type: application/json');
header('Access-Control-Allow-Origin: *');
header('Access-Control-Allow-Methods: POST, OPTIONS');
header('Access-Control-Allow-Headers: Content-Type');

// 如果是OPTIONS请求，直接返回200
if ($_SERVER['REQUEST_METHOD'] === 'OPTIONS') {
    http_response_code(200);
    exit;
}

// 引入数据库连接文件
require_once '../../config/database.php';

// 获取POST数据
$postData = json_decode(file_get_contents('php://input'), true);
if (!$postData) {
    $postData = $_POST;
}

$username = isset($postData['username']) ? trim($postData['username']) : '';
$password = isset($postData['password']) ? trim($postData['password']) : '';

if (empty($username) || empty($password)) {
    echo json_encode([
        'success' => false,
        'message' => '用户名和密码不能为空'
    ]);
    exit;
}

try {
    // 查询用户 - 适配mac_user表
    $stmt = $conn->prepare("SELECT * FROM mac_user WHERE user_name = ?");
    $stmt->bind_param("s", $username);
    $stmt->execute();
    $result = $stmt->get_result();
    
    if ($result->num_rows === 0) {
        echo json_encode([
            'success' => false,
            'message' => '用户名或密码错误'
        ]);
        exit;
    }
    
    $user = $result->fetch_assoc();
    
    // 验证密码 (根据您的密码存储方式调整)
    if ($user['user_pwd'] !== md5($password)) {
        echo json_encode([
            'success' => false,
            'message' => '用户名或密码错误'
        ]);
        exit;
    }
    
    // 生成token
    $token = bin2hex(random_bytes(32));
    $expireTime = time() + 86400 * 7; // 7天有效期
    
    // 更新用户token和最后登录时间
    $stmt = $conn->prepare("UPDATE mac_user SET user_token = ?, token_expire = ?, user_login_time = ? WHERE user_id = ?");
    $now = time();
    $stmt->bind_param("siii", $token, $expireTime, $now, $user['user_id']);
    $stmt->execute();
    
    // 返回用户信息
    echo json_encode([
        'success' => true,
        'token' => $token,
        'userInfo' => [
            'user_id' => $user['user_id'],
            'user_name' => $user['user_name'],
            'group_id' => $user['group_id'],
            'user_points' => $user['user_points'],
            'user_jifenlq' => $user['user_jifenlq'],
            'user_end_time' => $user['user_end_time']
        ]
    ]);
    
} catch (Exception $e) {
    echo json_encode([
        'success' => false,
        'message' => '登录失败: ' . $e->getMessage()
    ]);
}
?>