<?php
header('Content-Type: application/json');
header('Access-Control-Allow-Origin: *');
header('Access-Control-Allow-Methods: POST, OPTIONS');
header('Access-Control-Allow-Headers: Content-Type');

// 如果是OPTIONS请求，直接返回200
if ($_SERVER['REQUEST_METHOD'] === 'OPTIONS') {
    http_response_code(200);
    exit;
}

// 引入数据库连接文件
require_once '../../config/database.php';

// 获取POST数据
$postData = json_decode(file_get_contents('php://input'), true);
if (!$postData) {
    $postData = $_POST;
}

$token = isset($postData['token']) ? trim($postData['token']) : '';

if (empty($token)) {
    echo json_encode([
        'success' => false,
        'message' => '未提供token'
    ]);
    exit;
}

try {
    // 查询用户 - 适配mac_user表
    $stmt = $conn->prepare("SELECT user_id, user_points, user_jifenlq, user_qiandao, token_expire FROM mac_user WHERE user_token = ?");
    $stmt->bind_param("s", $token);
    $stmt->execute();
    $result = $stmt->get_result();
    
    if ($result->num_rows === 0) {
        echo json_encode([
            'success' => false,
            'message' => '无效的token'
        ]);
        exit;
    }
    
    $user = $result->fetch_assoc();
    
    // 检查token是否过期
    if ($user['token_expire'] < time()) {
        echo json_encode([
            'success' => false,
            'message' => 'token已过期'
        ]);
        exit;
    }
    
    // 检查今日是否已签到
    $today = date('Y-m-d');
    if ($user['user_qiandao'] == $today) {
        echo json_encode([
            'success' => false,
            'message' => '今日已签到'
        ]);
        exit;
    }
    
    // 计算签到奖励积分
    $points = rand(10, 20); // 随机10-20积分，与您原系统一致
    
    // 开始事务
    $conn->begin_transaction();
    
    try {
        // 添加积分记录 - 适配mac_plog表
        $plog_time = time();
        $plog_remarks = "签到获得";
        
        $stmt = $conn->prepare("INSERT INTO mac_plog (user_id, plog_points, plog_time, plog_remarks) VALUES (?, ?, ?, ?)");
        $stmt->bind_param("isis", $user['user_id'], $points, $plog_time, $plog_remarks);
        $stmt->execute();
        
        // 更新用户积分和签到日期 - 适配mac_user表
        $stmt = $conn->prepare("UPDATE mac_user SET user_points = user_points + ?, user_qiandao = ?, user_jifenlq = user_jifenlq + ? WHERE user_id = ?");
        $stmt->bind_param("isii", $points, $today, $points, $user['user_id']);
        $stmt->execute();
        
        // 获取新积分
        $newPoints = $user['user_points'] + $points;
        $newJifenlq = $user['user_jifenlq'] + $points;
        
        // 提交事务
        $conn->commit();
        
        echo json_encode([
            'success' => true,
            'message' => '签到成功',
            'points' => $points,
            'newPoints' => $newPoints,
            'newJifenlq' => $newJifenlq
        ]);
        
    } catch (Exception $e) {
        // 回滚事务
        $conn->rollback();
        throw $e;
    }
    
} catch (Exception $e) {
    echo json_encode([
        'success' => false,
        'message' => '签到失败: ' . $e->getMessage()
    ]);
}
?>