<?php
class Database {
    private $host = 'localhost';      
    private $username = '配置你的数据库用户名'; //数据库用户名       
    private $password = '配置你的数据库密码'; //数据库密码           
    private $dbname = '配置你的数据库名'; //数据库名称 
    private $charset = 'utf8mb4';   
    
    private $conn = null;             
    private $stmt = null;             
    private $error = '';              

    public function __construct($config = []) {
        
        if (!empty($config)) {
            if (isset($config['host'])) $this->host = $config['host'];
            if (isset($config['username'])) $this->username = $config['username'];
            if (isset($config['password'])) $this->password = $config['password'];
            if (isset($config['dbname'])) $this->dbname = $config['dbname'];
            if (isset($config['charset'])) $this->charset = $config['charset'];
        }
        
        
        $dsn = "mysql:host={$this->host};dbname={$this->dbname};charset={$this->charset}";
        $options = [
            PDO::ATTR_PERSISTENT => true,  
            PDO::ATTR_ERRMODE => PDO::ERRMODE_EXCEPTION, 
            PDO::ATTR_DEFAULT_FETCH_MODE => PDO::FETCH_ASSOC, 
            PDO::ATTR_EMULATE_PREPARES => false 
        ];
        
        try {
            $this->conn = new PDO($dsn, $this->username, $this->password, $options);
        } catch (PDOException $e) {
            $this->error = $e->getMessage();
            throw new Exception("数据库连接失败");
        }
    }
    
    public function getConnection() {
        return $this->conn;
    }
    

    public function query($sql) {
        try {
            $this->stmt = $this->conn->prepare($sql);
        } catch (PDOException $e) {
            $this->error = $e->getMessage();
            throw new Exception("SQL预处理失败");
        }
    }

    public function bind($param, $value, $type = null) {
        
        if (is_null($type)) {
            switch (true) {
                case is_int($value):
                    $type = PDO::PARAM_INT;
                    break;
                case is_bool($value):
                    $type = PDO::PARAM_BOOL;
                    break;
                case is_null($value):
                    $type = PDO::PARAM_NULL;
                    break;
                default:
                    $type = PDO::PARAM_STR;
            }
        }
        
        $this->stmt->bindValue($param, $value, $type);
    }

    public function execute() {
        try {
            return $this->stmt->execute();
        } catch (PDOException $e) {
            $this->error = $e->getMessage();
            throw new Exception("SQL执行失败: " . $this->error);
        }
    }

    public function resultSet() {
        $this->execute();
        return $this->stmt->fetchAll();
    }
    
    public function single() {
        $this->execute();
        return $this->stmt->fetch();
    }

    public function rowCount() {
        return $this->stmt->rowCount();
    }
    
    public function lastInsertId() {
        return $this->conn->lastInsertId();
    }

    public function beginTransaction() {
        return $this->conn->beginTransaction();
    }
    

    public function commit() {
        return $this->conn->commit();
    }
    
    public function rollback() {
        return $this->conn->rollBack();
    }

    public function getError() {
        return $this->error;
    }
    
    public function inTransaction() {
        return $this->conn->inTransaction();
    }
    
    public function __destruct() {
        if ($this->stmt !== null) {
            $this->stmt = null;
        }
        if ($this->conn !== null) {
            $this->conn = null;
        }
    }
} 